@@ -24,7 +24,10 @@ import gettext
 gettext.install("ibus-libpinyin")
 
 def get_version():
-    return "1.11.1"
+    return "1.12.0"
 
 def get_longname():
     return _("Intelligent Pinyin")
+
+def support_cloud_input():
+    return True
